"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KnapsackHtmlRenderer = void 0;
const app_1 = require("@knapsack/app");
const file_utils_1 = require("@knapsack/file-utils");
const path_1 = require("path");
const { pkg } = (0, file_utils_1.findUpPkgJson)(__dirname);
app_1.log.setupUpdateNotifier({
    name: pkg.name,
    version: pkg.version,
});
const gitRoot = (0, file_utils_1.findGitRoot)();
class KnapsackHtmlRenderer extends app_1.KnapsackRendererBase {
    constructor() {
        super({
            id: 'html',
            extension: '.html',
            language: 'html',
        });
        this.getMeta = () => ({
            id: this.id,
            title: 'HTML',
            syntaxHighlightingLanguage: 'html',
            aliasUse: 'off',
            enableDataDemos: false,
            enableTemplateDemos: true,
            hasSlotsSupport: false,
            version: pkg.version,
            hasInferSpecSupport: false,
            hasTemplateSuggestionsSupport: true,
        });
    }
    async render(opt) {
        try {
            const usage = await this.getUsage(opt);
            return {
                ok: true,
                html: app_1.KnapsackRendererBase.formatCode({
                    code: usage,
                    language: 'html',
                }),
            };
        }
        catch (e) {
            return {
                ok: false,
                html: `<p>${e.message}</p>`,
                message: e.message,
            };
        }
    }
    async getUsage({ pattern, template, demo, patternManifest, }) {
        if (app_1.KnapsackRendererBase.isTemplateDemo(demo)) {
            const templateDemoPath = patternManifest.getTemplateDemoAbsolutePath({
                patternId: pattern.id,
                templateId: template.id,
                demoId: demo.id,
            });
            return (0, file_utils_1.readFile)(templateDemoPath);
        }
        try {
            const templatePath = patternManifest.getTemplateAbsolutePath({
                patternId: pattern.id,
                templateId: template.id,
            });
            return (0, file_utils_1.readFile)(templatePath);
        }
        catch (e) {
            console.log(e);
            const msg = `Error getting pattern "${pattern.id}" template "${template.id}": ${e.message}`;
            app_1.log.error(msg);
            throw new Error(msg);
        }
    }
    async getTemplateSuggestions() {
        const { unusedPaths } = await this.getUnusedTemplatePaths({
            globPaths: [(0, path_1.join)(gitRoot, '**/*.html')],
        });
        return {
            suggestions: unusedPaths.map((path) => ({
                path,
            })),
        };
    }
}
exports.KnapsackHtmlRenderer = KnapsackHtmlRenderer;
//# sourceMappingURL=index.js.map